@@ -6,15 +6,14 @@ use Carp qw(croak carp);
 use strict;
 use warnings;
 BEGIN {
-  $REST::Neo4p::Relationship::VERSION = '0.3012';
-  $REST::Neo4p::Relationship::VERSION = '0.3012';
+  $REST::Neo4p::Relationship::VERSION = '0.3020';
 }
 
 sub new {
   my $self = shift;
   my ($from_node, $to_node, $type, $rel_props) = @_;
-  unless (ref $from_node && $from_node->is_a('REST::Neo4p::Node') &&
-	  ref $to_node && $to_node->is_a('REST::Neo4p::Node') &&
+  unless (ref $from_node && $from_node->isa('REST::Neo4p::Node') &&
+	  ref $to_node && $to_node->isa('REST::Neo4p::Node') &&
 	  defined $type) {
     REST::Neo4p::LocalException->throw("Requires 2 REST::Neo4p::Node objects and a relationship type\n");
   }
@@ -68,7 +67,7 @@ REST::Neo4p::Relationship - Neo4j relationship object
 
 =head1 SYNOPSIS
 
- $n1 = REST::Neo4p::Node->new( {name => 'Harry'} )
+ $n1 = REST::Neo4p::Node->new( {name => 'Harry'} );
  $n2 = REST::Neo4p::Node->new( {name => 'Sally'} );
  $r1 = $n1->relate_to($n2, 'met');
  $r1->set_property({ when => 'July' });
@@ -161,7 +160,7 @@ L<REST::Neo4p>, L<REST::Neo4p::Node>, L<REST::Neo4p::Index>.
 
 =head1 LICENSE
 
-Copyright (c) 2012-2015 Mark A. Jensen. This program is free software; you
+Copyright (c) 2012-2017 Mark A. Jensen. This program is free software; you
 can redistribute it and/or modify it under the same terms as Perl
 itself.
 
